@@ -28,7 +28,7 @@
 
 class MachineConfigDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	MachineConfigDialog(LDAPMachineInfo machine, TQString realmName, LDAPConfig* parent = 0, const char* name = 0);
